`lura` is a collection of devops-oriented utility modules.

| Module           | Description                                                                |
| ---------------- | -------------------------------------------------------------------------- |
| `assets`         | syntactic sugar for `pkg_resources`                                        |
| `at`             | api for periodic task scheduling using `schedule`                          |
| `attrs`          | `dict`s with keys accessible as attributes                                 |
| `click`          | click helpers                                                              |
| `expanders`      | api for expanding templates with jinja2, etc.                              |
| `formats`        | api for dealing with json, yaml, csv, etc.                                 |
| `fs`             | filesystem helpers                                                         |
| `hash`           | syntactic sugar for hashlib                                                |
| `logutils`       | extensions for logging and an easy package-level configurator              |
| `messaging`      | api for sending messages to discord, teams, etc.                           |
| `rpc`            | syntactic sugar for `rpyc`                                                 |
| `run`            | popen front-end with sudo support                                          |
| `threads`        | threads which capture their results and exceptions                         |
| `time`           | time utilities                                                             |
